On 9/17/20 10:17 AM, Markus Armbruster wrote:
John Snow <js...@redhat.com> writes:

Signed-off-by: John Snow <js...@redhat.com>
---
  scripts/qapi/common.py | 8 ++++----
  1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/scripts/qapi/common.py b/scripts/qapi/common.py
index c665e67495..4c079755d3 100644
--- a/scripts/qapi/common.py
+++ b/scripts/qapi/common.py
@@ -30,14 +30,14 @@ def camel_to_upper(value):
      new_name = ''
      length = len(c_fun_str)
      for i in range(length):
-        c = c_fun_str[i]
-        # When c is upper and no '_' appears before, do more checks
-        if c.isupper() and (i > 0) and c_fun_str[i - 1] != '_':
+        char = c_fun_str[i]
+        # When char is upper and no '_' appears before, do more checks

Good opportunity to tweak the language: "When char is upper case".


ACK, change made.


Reply via email to